@@ -27,6 +27,10 @@ def make_executable(environment : Environment, command : str) -> int:
     Returns:
         Return code of the subprocess executed with PyInstaller.
     """
-    if environment.dependency_exists('pyinstaller') is None:
-        pip.install('pyinstaller')
-    return process_utils.create_process(str(environment.python()), command)
\ No newline at end of file
+    if environment.dependency_exists('pyinstaller') == (None, None):
+        pip.install(environment, 'pyinstaller')
+    pyinstaller_executable = [x for x in environment.executables() if 'pyinstaller' in x.name]
+    if not pyinstaller_executable: 
+        raise FileNotFoundError('Unable to locate pyinstaller executable.')
+    pyinstaller_executable = pyinstaller_executable[0]
+    return process_utils.create_process(str(pyinstaller_executable), command)
\ No newline at end of file
